# Radio field

The radio field is a standard input type radio

![Radio fields](../screenshots/fields/waf-radio-field.png)

## Configuration options

There are a number of fields that can be manipulated to serve a radio field

### Label

The 'name' of the field

### Required

Whether or not it is a required field

### Choices

Radio choices

### Default value

Set a default radio button to check

### Help text

Set the help text to sit alongside the field

### Display side by side

Whether or not the radio buttons should display in a flex row or stack vertically

### Rules and conditions

Set conditional display rules based on other form field values.


